@@ -207,7 +207,7 @@ aboot <- function(x, strata = NULL, tree = "upgma", distance = "nei.dist",
                   mcutoff = 0, quiet = FALSE, root = NULL, ...){
   if (!is.null(strata)){
     if (!is.genind(x)){
-      warning("The strata argument can only be used with genind objects.")
+      warning("Sorry, the strata argument can only be used with genind objects.")
     } else {
       x <- genind2genpop(x, pop = strata, quiet = TRUE, process.other = FALSE)
     }
@@ -235,7 +235,7 @@ aboot <- function(x, strata = NULL, tree = "upgma", distance = "nei.dist",
     if (length(distname) == 1 && distname %in% "diss.dist"){
       if (missing == "mean"){
         missing <- "asis"
-        warning("missing = 'mean' is incompatible with diss.dist(), setting missing to 'asis'", 
+        warning("Sorry, missing = 'mean' is incompatible with diss.dist(), setting missing to 'asis'.", 
                 call. = FALSE)
       }
       xboot <- new("bootgen", x, na = missing, freq = FALSE)
@@ -248,11 +248,11 @@ aboot <- function(x, strata = NULL, tree = "upgma", distance = "nei.dist",
                   "reynolds.dist", "rogers.dist", "provesti.dist")
     wrong_dist <- any(as.character(substitute(distance)) %in% my_dists)
     if (wrong_dist){
-      warning("distance from genlight objects can only be calculated by bitwise.dist.")
+      warning("Sorry, distance from genlight objects can only be calculated by bitwise.dist.")
       distance <- bitwise.dist
     }
   } else {
-    stop("x must be a genind, genpop, or genlight object.")
+    stop("Sorry, x must be a genind, genpop, or genlight object.")
   }
   treefunk <- tree_generator(tree, distance, ...)
   xtree    <- treefunk(xboot)
@@ -643,7 +643,7 @@ diversity_ci <- function(tab, n = 1000, n.boot = 1L, ci = 95, total = TRUE,
   rareval <- NULL
   if (rarefy){
     rareval <- max(min(rowSums(tab)), n.rare)
-    msg <- paste("\nSamples for rarefaction:", rareval)
+    msg     <- paste("\nSamples for rarefaction:", rareval)
     message(msg)
   } else {
     if (center == TRUE){
@@ -662,21 +662,18 @@ diversity_ci <- function(tab, n = 1000, n.boot = 1L, ci = 95, total = TRUE,
   orig <- get_boot_stats(res)
   statnames <- colnames(orig)
   CI  <- get_all_ci(res, ci = ci, index_names = statnames, 
-                    center = ifelse(rarefy, FALSE, center),
-                    btype = ifelse(rarefy, "percent", "normal"),
-                    bci = ifelse(rarefy, FALSE, TRUE))
+                    center = if (rarefy) FALSE else center,
+                    btype =  if (rarefy) "percent" else "normal",
+                    bci =    if (rarefy) FALSE else TRUE)
   est <- get_boot_se(res, "mean")
   out <- list(obs = orig, est = est, CI = CI, boot = res)
-  if (plot){
-    if (rarefy){
-      boot_plot(res, orig, statnames, rownames(tab), NULL)
-    } else {
-      boot_plot(res, orig, statnames, rownames(tab), CI)      
-    }
-  }
-  if (!raw){
-    out <- do.call("pretty_info", out)
+  if (plot) {
+    boot_plot(res = res, 
+              orig = orig,  
+              CI = if (rarefy) NULL else CI
+              )
   }
+  out <- if (raw) out else do.call("pretty_info", out)
   return(out)
 }
 
